@@ -1,20 +1,7 @@
 /*
-*   Copyright (C) 2017 by Marco Martin <mart@kde.org>
-*
-*   This program is free software; you can redistribute it and/or modify
-*   it under the terms of the GNU Library General Public License as
-*   published by the Free Software Foundation; either version 2, or
-*   (at your option) any later version.
-*
-*   This program is distributed in the hope that it will be useful,
-*   but WITHOUT ANY WARRANTY; without even the implied warranty of
-*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-*   GNU Library General Public License for more details
-*
-*   You should have received a copy of the GNU Library General Public
-*   License along with this program; if not, write to the
-*   Free Software Foundation, Inc.,
-*   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+    SPDX-FileCopyrightText: 2017 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "plasmadesktoptheme.h"
@@ -24,7 +11,6 @@
 #include <QPalette>
 #include <QDebug>
 #include <QQuickWindow>
-#include <QTimer>
 #include <KIconLoader>
 
 #include <KColorScheme>
@@ -144,7 +130,7 @@ Q_GLOBAL_STATIC_WITH_ARGS(QScopedPointer<StyleSingleton>, s_style, (new StyleSin
 PlasmaDesktopTheme::PlasmaDesktopTheme(QObject *parent)
     : PlatformTheme(parent)
 {
-   // setHasCustomIconColoring(true);
+    setSupportsIconColoring(true);
     m_parentItem = qobject_cast<QQuickItem *>(parent);
 
     //null in case parent is a normal QObject
@@ -232,7 +218,14 @@ void PlasmaDesktopTheme::syncColors()
 
     //background
     setBackgroundColor(colors.scheme.background(KColorScheme::NormalBackground).color());
+    setAlternateBackgroundColor(colors.scheme.background(KColorScheme::AlternateBackground).color());
     setHighlightColor(colors.selectionScheme.background(KColorScheme::NormalBackground).color());
+    setActiveBackgroundColor(colors.scheme.background(KColorScheme::ActiveBackground).color());
+    setLinkBackgroundColor(colors.scheme.background(KColorScheme::LinkBackground).color());
+    setVisitedLinkBackgroundColor(colors.scheme.background(KColorScheme::VisitedBackground).color());
+    setNegativeBackgroundColor(colors.scheme.background(KColorScheme::NegativeBackground).color());
+    setNeutralBackgroundColor(colors.scheme.background(KColorScheme::NeutralBackground).color());
+    setPositiveBackgroundColor(colors.scheme.background(KColorScheme::PositiveBackground).color());
 
     //decoration
     setHoverColor(colors.scheme.decoration(KColorScheme::HoverColor).color());
